=======
Credits
=======

Development Leads
-----------------

* Reza Hosseini <rhosseini@linkedin.com> (Core Algorithms and Models)
* Albert Chen <abchen@linkedin.com> (Modeling Framework, Templates, Auto-tuning)

Authors
-------
* Reza Hosseini
* Albert Chen
* Kaixu Yang
* Sayan Patra
* Rachit Arora

Other Contributors
------------------
* Saad Eddin Al Orjany
* Rachit Kumar
